@@ -41,8 +41,8 @@
 
 #include "commandtype.h"
 
-#include <QStringList>
-#include <QVariant>
+#include <QtCore/qstringlist.h>
+#include <QtCore/qvariant.h>
 
 namespace qbs {
 class BuildOptions;
@@ -63,6 +63,7 @@ public:
 
     CommandType command() const;
     QString commandName() const;
+    bool commandCanResolve() const;
     QString commandDescription() const;
     QString projectFilePath() const;
     QString projectBuildDirectory() const;
@@ -70,7 +71,6 @@ public:
     CleanOptions cleanOptions(const QString &profile) const;
     GenerateOptions generateOptions() const;
     InstallOptions installOptions(const QString &profile) const;
-    bool force() const;
     bool forceTimestampCheck() const;
     bool forceOutputCheck() const;
     bool dryRun() const;
