@@ -1,30 +1,39 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of Qbs.
 **
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms and
-** conditions see http://www.qt.io/terms-conditions. For further information
-** use the contact form at http://www.qt.io/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** In addition, as a special exception, The Qt Company gives you certain additional
-** rights.  These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
+**
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 #ifndef QBS_BUILDGRAPHLOADER_H
@@ -32,15 +41,15 @@
 
 #include "forward_decls.h"
 
+#include "artifact.h"
 #include "rescuableartifactdata.h"
 
-#include <buildgraph/artifactset.h>
 #include <language/forward_decls.h>
 #include <logging/logger.h>
 #include <tools/setupprojectparameters.h>
 
-#include <QProcessEnvironment>
-#include <QVariantMap>
+#include <QtCore/qprocess.h>
+#include <QtCore/qvariant.h>
 
 namespace qbs {
 
@@ -48,7 +57,6 @@ namespace Internal {
 class FileDependency;
 class FileResourceBase;
 class FileTime;
-class NodeSet;
 class Property;
 
 class BuildGraphLoadResult
@@ -62,17 +70,21 @@ public:
 class BuildGraphLoader
 {
 public:
-    BuildGraphLoader(const QProcessEnvironment &env, const Logger &logger);
+    BuildGraphLoader(const Logger &logger);
     ~BuildGraphLoader();
 
     BuildGraphLoadResult load(const TopLevelProjectPtr &existingProject,
                               const SetupProjectParameters &parameters,
                               const RulesEvaluationContextPtr &evalContext);
 
+    static TopLevelProjectConstPtr loadProject(const QString &bgFilePath);
+
 private:
     void loadBuildGraphFromDisk();
-    void checkBuildGraphCompatibility(const TopLevelProjectConstPtr &project);
+    bool checkBuildGraphCompatibility(const TopLevelProjectConstPtr &project);
     void trackProjectChanges();
+    bool probeExecutionForced(const TopLevelProjectConstPtr &restoredProject,
+                              const QList<ResolvedProductPtr> &restoredProducts) const;
     bool hasEnvironmentChanged(const TopLevelProjectConstPtr &restoredProject) const;
     bool hasCanonicalFilePathResultChanged(const TopLevelProjectConstPtr &restoredProject) const;
     bool hasFileExistsResultChanged(const TopLevelProjectConstPtr &restoredProject) const;
@@ -80,9 +92,9 @@ private:
     bool hasFileLastModifiedResultChanged(const TopLevelProjectConstPtr &restoredProject) const;
     bool hasProductFileChanged(const QList<ResolvedProductPtr> &restoredProducts,
                                const FileTime &referenceTime,
-                               QSet<QString> &remainingBuildSystemFiles,
+                               Set<QString> &remainingBuildSystemFiles,
                                QList<ResolvedProductPtr> &productsWithChangedFiles);
-    bool hasBuildSystemFileChanged(const QSet<QString> &buildSystemFiles,
+    bool hasBuildSystemFileChanged(const Set<QString> &buildSystemFiles,
                                    const FileTime &referenceTime);
     void checkAllProductsForChanges(const QList<ResolvedProductPtr> &restoredProducts,
             const QMap<QString, ResolvedProductPtr> &newlyResolvedProductsByName,
@@ -93,17 +105,18 @@ private:
                                            const ResolvedProductPtr &newlyResolvedProduct);
     bool checkForPropertyChanges(const ResolvedProductPtr &restoredProduct,
                                  const ResolvedProductPtr &newlyResolvedProduct);
-    bool checkTransformersForPropertyChanges(const ResolvedProductPtr &restoredProduct,
+    bool checkTransformersForChanges(const ResolvedProductPtr &restoredProduct,
                                              const ResolvedProductPtr &newlyResolvedProduct);
     void onProductRemoved(const ResolvedProductPtr &product, ProjectBuildData *projectBuildData,
                           bool removeArtifactsFromDisk = true);
     bool checkForPropertyChanges(const TransformerPtr &restoredTrafo,
             const ResolvedProductPtr &freshProduct);
+    bool checkForEnvChanges(const TransformerPtr &restoredTrafo);
     bool checkForPropertyChange(const Property &restoredProperty,
                                 const QVariantMap &newProperties);
     void replaceFileDependencyWithArtifact(const ResolvedProductPtr &fileDepProduct,
             FileDependency *filedep, Artifact *artifact);
-    bool isConfigCompatible();
+    bool checkConfigCompatibility();
     bool isPrepareScriptUpToDate(const ScriptFunctionConstPtr &script,
                                  const FileTime &referenceTime);
 
@@ -117,7 +130,6 @@ private:
     typedef QHash<const Artifact *, ChildrenInfo> ChildListHash;
     void rescueOldBuildData(const ResolvedProductConstPtr &restoredProduct,
                             const ResolvedProductPtr &newlyResolvedProduct,
-                            ProjectBuildData *oldBuildData,
                             const ChildListHash &childLists,
                             const AllRescuableArtifactData &existingRad);
 
@@ -125,11 +137,14 @@ private:
     SetupProjectParameters m_parameters;
     BuildGraphLoadResult m_result;
     Logger m_logger;
-    QProcessEnvironment m_environment;
     QStringList m_artifactsRemovedFromDisk;
+    qint64 m_wildcardExpansionEffort;
+    qint64 m_propertyComparisonEffort;
 
     // These must only be deleted at the end so we can still peek into the old look-up table.
     QList<FileResourceBase *> m_objectsToDelete;
+
+    bool m_envChange = false;
 };
 
 } // namespace Internal
