@@ -41,7 +41,7 @@
 
 #include <tools/jsliterals.h>
 #include <tools/persistence.h>
-#include <tools/propertyfinder.h>
+#include <tools/scripttools.h>
 
 namespace qbs {
 namespace Internal {
@@ -67,9 +67,20 @@ PropertyMapInternal::PropertyMapInternal(const PropertyMapInternal &other)
 {
 }
 
+QVariant PropertyMapInternal::moduleProperty(const QString &moduleName,
+                                                  const QString &key) const
+{
+    return ::qbs::Internal::moduleProperty(m_value, moduleName, key);
+}
+
 QVariant PropertyMapInternal::qbsPropertyValue(const QString &key) const
 {
-    return PropertyFinder().propertyValue(value(), QLatin1String("qbs"), key);
+    return moduleProperty(QLatin1String("qbs"), key);
+}
+
+QVariant PropertyMapInternal::property(const QStringList &name) const
+{
+    return getConfigProperty(m_value, name);
 }
 
 void PropertyMapInternal::setValue(const QVariantMap &map)
@@ -77,33 +88,9 @@ void PropertyMapInternal::setValue(const QVariantMap &map)
     m_value = map;
 }
 
-static QString toJSLiteral_impl(const QVariantMap &vm, int level = 0)
-{
-    QString indent;
-    for (int i = 0; i < level; ++i)
-        indent += QLatin1String("    ");
-    QString str;
-    for (QVariantMap::const_iterator it = vm.begin(); it != vm.end(); ++it) {
-        if (it.value().type() == QVariant::Map) {
-            str += indent + it.key() + QLatin1String(": {\n");
-            str += toJSLiteral_impl(it.value().toMap(), level + 1);
-            str += indent + QLatin1String("}\n");
-        } else {
-            str += indent + it.key() + QLatin1String(": ") + toJSLiteral(it.value())
-                    + QLatin1Char('\n');
-        }
-    }
-    return str;
-}
-
-QString PropertyMapInternal::toJSLiteral() const
-{
-    return toJSLiteral_impl(m_value);
-}
-
 void PropertyMapInternal::load(PersistentPool &pool)
 {
-    m_value = pool.loadVariantMap();
+    pool.load(m_value);
 }
 
 void PropertyMapInternal::store(PersistentPool &pool) const
@@ -111,5 +98,12 @@ void PropertyMapInternal::store(PersistentPool &pool) const
     pool.store(m_value);
 }
 
+QVariant moduleProperty(const QVariantMap &properties, const QString &moduleName,
+                        const QString &key)
+{
+    const QVariantMap moduleProperties = properties.value(QLatin1String("modules")).toMap();
+    return moduleProperties.value(moduleName).toMap().value(key);
+}
+
 } // namespace Internal
 } // namespace qbs
